import{O as r}from"./index.8b4fa436.js";import{d as l,o as i,b as u,eq as c,f as o,w as a,u as n,ak as d,cM as f,cL as _}from"./outputWidgets.f7b80e9f.js";import"./fetch.1ec4f78f.js";import"./pubsub.10df5fd2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3861d174-f26c-4d2d-8e51-32fb5556d23e",e._sentryDebugIdIdentifier="sentry-dbid-3861d174-f26c-4d2d-8e51-32fb5556d23e")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[o(n(f),null,{default:a(()=>[d("You're authenticated")]),_:1}),o(n(_),null,{default:a(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.581b5193.js.map
