import{_ as B}from"./logo.084e5d7c.js";import{E as x,b as r,eq as _,ew as C,ex as I,e as c,d as k,eF as L,a as N,u as e,c as i,bc as S,f as a,w as t,ak as n,bz as d,cL as $,eC as m,cr as D,D as z,eA as V,f8 as E,aw as b,es as F,dv as R}from"./outputWidgets.f7b80e9f.js";import{a as T}from"./asyncComputed.bd2b6e70.js";import{G as q}from"./PhChats.vue.9e85add8.js";import{F as P}from"./PhSignOut.vue.3641a16f.js";import{C as j}from"./router.6fb3acdf.js";import{a as h}from"./gateway.58b63376.js";import{A as G}from"./index.86fdb625.js";import{A as H}from"./index.956edd16.js";import{B as M,A as O,b as U}from"./index.c4af5543.js";import{B as J}from"./BookOutlined.12f9401e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[s]="27533aa3-7f77-4358-a57d-d8a616906ffa",o._sentryDebugIdIdentifier="sentry-dbid-27533aa3-7f77-4358-a57d-d8a616906ffa")}catch{}})();const K={},v=o=>(C("data-v-46e041c1"),o=o(),I(),o),Q={class:"logo"},W=v(()=>c("img",{class:"logo-img",src:B,alt:"Abstra cloud logo"},null,-1)),X=v(()=>c("span",null,"Abstra",-1)),Y=[W,X];function Z(o,s){return r(),_("div",Q,Y)}const ee=x(K,[["render",Z],["__scopeId","data-v-46e041c1"]]),te={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},ae={style:{display:"flex","flex-direction":"column",gap:"10px"}},oe={style:{display:"flex",gap:"5px"}},se=k({__name:"LoginBlock",setup(o){function s(g){const y=g.split("@")[0];return z.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(f=>f[0]).join("")}const p=L(),{result:l,loading:u,refetch:A}=T(async()=>h.getAuthor());function w(){h.removeAuthor(),j.shutdown(),A(),p.push({name:"login"})}return(g,y)=>{const f=N("router-link");return e(u)?(r(),i(e(S),{key:0})):e(l)?(r(),_("div",te,[a(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e(q),{size:18})]),default:t(()=>[n(" Support ")]),_:1}),a(e(D),{placement:"bottomRight"},{content:t(()=>[c("div",ae,[a(e($),{size:"small",type:"secondary"},{default:t(()=>[n(m(e(l).claims.email),1)]),_:1}),a(e(d),{type:"text",onClick:w},{default:t(()=>[c("div",oe,[a(e(P),{size:"20"}),n(" Logout ")])]),_:1})])]),default:t(()=>[a(e(G),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(H),{shape:"square"},{default:t(()=>[n(m(s(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(r(),i(e(d),{key:2},{default:t(()=>[a(f,{to:"/login"},{default:t(()=>[n("Login")]),_:1})]),_:1}))}}}),re={class:"extra"},ne=k({__name:"Navbar",props:{breadcrumb:{}},setup(o){return(s,p)=>(r(),i(e(U),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[s.breadcrumb?(r(),i(e(M),{key:0,style:{margin:"0px 50px"}},{default:t(()=>[(r(!0),_(b,null,V(s.breadcrumb,(l,u)=>(r(),i(e(O),{key:u},{default:t(()=>[a(e(E),{to:l.path},{default:t(()=>[n(m(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[a(ee)]),extra:t(()=>[c("div",re,[a(e(d),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(J))]),default:t(()=>[s.$slots.default?R(s.$slots,"default",{key:0},void 0,!0):(r(),_(b,{key:1},[n("Docs")],64))]),_:3}),a(se)])]),_:3}))}});const be=x(ne,[["__scopeId","data-v-31e2a422"]]);export{be as N};
//# sourceMappingURL=Navbar.669ea9c8.js.map
