import{d as n,b as o,eq as s,e as a,dv as c,eu as r,E as l}from"./outputWidgets.f7b80e9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3a8b03ad-92bd-4c0c-85e7-7a1b56ec8ddc",e._sentryDebugIdIdentifier="sentry-dbid-3a8b03ad-92bd-4c0c-85e7-7a1b56ec8ddc")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,d)=>(o(),s("div",_,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[c(t.$slots,"default",{},void 0,!0)],2)]))}});const f=l(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.129025ab.js.map
