import{C as y}from"./ContentLayout.129025ab.js";import{d,L as w,z as l,r as g,b as a,c as i,w as f,f as n,u as o,es as s}from"./outputWidgets.f7b80e9f.js";import{K as _,_ as v,W as K,E,a as R}from"./WorkflowView.d1fc198a.js";import{E as T}from"./api.b0b5d442.js";import{A as p,T as V}from"./TabPane.7d974707.js";import"./fetch.1ec4f78f.js";import"./workspaces.9eccf428.js";import"./asyncComputed.bd2b6e70.js";import"./runnerData.5347d4ed.js";import"./url.882128c4.js";import"./record.188928bf.js";import"./pubsub.10df5fd2.js";import"./scripts.cb8e267f.js";import"./metadata.e0926a4e.js";import"./PhCheckCircle.vue.902dac5a.js";import"./PhKanban.vue.34c60c18.js";import"./PhScroll.vue.26add44e.js";import"./PhWebhooksLogo.vue.4f41bfe0.js";import"./ant-design.505ee29f.js";import"./index.86fdb625.js";import"./index.288a68e3.js";import"./index.df77b543.js";import"./index.88a5774d.js";import"./CollapsePanel.9aa09d5a.js";import"./index.28e83ea9.js";import"./index.f3e992fc.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.d21a3af1.js";import"./model.d7c37a50.js";import"./validations.a9770be1.js";import"./string.18a9daee.js";import"./PhArrowSquareOut.vue.f5352ec6.js";import"./index.d7b009c6.js";import"./Badge.c2f08ef0.js";import"./index.9a5a7c1a.js";import"./Card.3d001ab8.js";import"./uuid.e5064b5a.js";import"./LoadingOutlined.38ef4163.js";import"./DeleteOutlined.c2ccfda8.js";import"./PhDownloadSimple.vue.eb3a15a1.js";import"./utils.7b8329eb.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="c23cc999-eb15-4061-a7c6-761b5f5689c9",r._sentryDebugIdIdentifier="sentry-dbid-c23cc999-eb15-4061-a7c6-761b5f5689c9")}catch{}})();const ko=d({__name:"WorkflowThreads",setup(r){const t=new E,m=new R,c=new w(l.array(l.string()),"kanban-selected-stages"),u=new T,e=g("kanban");return(W,b)=>(a(),i(y,{"full-width":""},{default:f(()=>[n(o(V),{activeKey:e.value,"onUpdate:activeKey":b[0]||(b[0]=k=>e.value=k)},{default:f(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),e.value==="kanban"?(a(),i(_,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(c),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),e.value==="table"?(a(),i(v,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),e.value==="workflow"?(a(),i(K,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{ko as default};
//# sourceMappingURL=WorkflowThreads.5d4544c4.js.map
