import{g as _}from"./api.aba07d9c.js";import{W as g}from"./Watermark.1f03c5f5.js";import{i as h}from"./metadata.e0926a4e.js";import{a as k}from"./asyncComputed.bd2b6e70.js";import{W as b}from"./WidgetsFrame.e878f348.js";import{F as w}from"./PhArrowSquareOut.vue.f5352ec6.js";import{d as x,eF as v,y as C,u as e,b as s,c,w as a,es as F,f as n,cI as d,ak as f,eq as I,eA as D,cQ as u,eB as W,eC as B,aw as T,E as V}from"./outputWidgets.f7b80e9f.js";import"./index.6afb8d54.js";import{C as z}from"./Card.3d001ab8.js";import"./index.8b4fa436.js";import"./fetch.1ec4f78f.js";import"./pubsub.10df5fd2.js";import"./runnerData.5347d4ed.js";import"./url.882128c4.js";import"./PhCheckCircle.vue.902dac5a.js";import"./PhKanban.vue.34c60c18.js";import"./PhScroll.vue.26add44e.js";import"./PhWebhooksLogo.vue.4f41bfe0.js";import"./TabPane.7d974707.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="912540b8-e33f-4e42-847b-142e631dfcf9",o._sentryDebugIdIdentifier="sentry-dbid-912540b8-e33f-4e42-847b-142e631dfcf9")}catch{}})();const E=x({__name:"Home",setup(o){const i=v(),{result:t}=k(_),p=C(()=>{var r;return((r=t.value)==null?void 0:r.sidebar.filter(l=>l.id!=="home"))||[]}),y=r=>{i.push({path:`/${r}`})};return(r,l)=>e(t)?(s(),c(b,{key:0,class:"home-container","main-color":e(t).mainColor,theme:e(t).theme,"font-family":e(t).fontFamily},{default:a(()=>[n(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:a(()=>[p.value.length===0?(s(),c(e(d),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:a(()=>[f(" There are no forms available for you. ")]),_:1})):(s(!0),I(T,{key:1},D(p.value,m=>(s(),c(e(z),{key:m.id,class:"form-card",onClick:H=>y(m.path)},{default:a(()=>[n(e(u),{gap:"large",align:"center",justify:"space-between"},{default:a(()=>[(s(),c(W(e(h)(m.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),n(e(d),{style:{"font-size":"18px","font-weight":"500"}},{default:a(()=>[f(B(m.name),1)]),_:2},1024),n(e(w),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),n(g,{class:"watermark","page-id":"home"})]),_:1},8,["main-color","theme","font-family"])):F("",!0)}});const ee=V(E,[["__scopeId","data-v-c7d28f54"]]);export{ee as default};
//# sourceMappingURL=Home.825dafa8.js.map
