import{u as n}from"./index.8b4fa436.js";import"./outputWidgets.f7b80e9f.js";import{r as s,w as a}from"./runnerData.5347d4ed.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cd663eeb-6c83-4b1d-aeab-d924c8310e08",e._sentryDebugIdIdentifier="sentry-dbid-cd663eeb-6c83-4b1d-aeab-d924c8310e08")}catch{}})();async function c(e){const t=await fetch(`/_pages/${e}`,{headers:n.authHeaders()});if(t.status===404)return null;if(!t.ok)throw new Error(await t.text());const{form:r}=await t.json();return r?s(r):null}async function f(){const e=await fetch("/_workspace",{headers:n.authHeaders()});if(e.status!=200)return a({});const t=await e.json();return a(t)}export{c as f,f as g};
//# sourceMappingURL=api.aba07d9c.js.map
