import{u as i}from"./index.8b4fa436.js";import{d as u,L as k,z as c,r as _,b as n,eq as w,f as s,w as g,u as e,c as p,es as m,E as v}from"./outputWidgets.f7b80e9f.js";import{K as T,_ as K,W as h,P as I,b as P}from"./WorkflowView.d1fc198a.js";import{P as R}from"./api.b0b5d442.js";import{A as b,T as V}from"./TabPane.7d974707.js";import"./Card.3d001ab8.js";import"./fetch.1ec4f78f.js";import"./pubsub.10df5fd2.js";import"./workspaces.9eccf428.js";import"./asyncComputed.bd2b6e70.js";import"./runnerData.5347d4ed.js";import"./url.882128c4.js";import"./record.188928bf.js";import"./scripts.cb8e267f.js";import"./metadata.e0926a4e.js";import"./PhCheckCircle.vue.902dac5a.js";import"./PhKanban.vue.34c60c18.js";import"./PhScroll.vue.26add44e.js";import"./PhWebhooksLogo.vue.4f41bfe0.js";import"./ant-design.505ee29f.js";import"./index.86fdb625.js";import"./index.288a68e3.js";import"./index.df77b543.js";import"./index.88a5774d.js";import"./CollapsePanel.9aa09d5a.js";import"./index.28e83ea9.js";import"./index.f3e992fc.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.d21a3af1.js";import"./model.d7c37a50.js";import"./validations.a9770be1.js";import"./string.18a9daee.js";import"./PhArrowSquareOut.vue.f5352ec6.js";import"./index.d7b009c6.js";import"./Badge.c2f08ef0.js";import"./index.9a5a7c1a.js";import"./uuid.e5064b5a.js";import"./LoadingOutlined.38ef4163.js";import"./DeleteOutlined.c2ccfda8.js";import"./PhDownloadSimple.vue.eb3a15a1.js";import"./utils.7b8329eb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="650d10d9-fbb7-4cfc-9f9e-cbf2712429e4",t._sentryDebugIdIdentifier="sentry-dbid-650d10d9-fbb7-4cfc-9f9e-cbf2712429e4")}catch{}})();const x={class:"threads-view"},W=u({__name:"Threads",setup(t){const a=new R(i),r=new I(i),f=new P(i),d=new k(c.array(c.string()),"kanban-selected-stages"),o=_("kanban");return(A,l)=>(n(),w("div",x,[s(e(V),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=y=>o.value=y)},{default:g(()=>[s(e(b),{key:"kanban",tab:"Kanban View"}),s(e(b),{key:"table",tab:"Table View"}),s(e(b),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(n(),p(T,{key:0,"kanban-repository":e(r),"kanban-stages-storage":e(d),"stage-run-repository":e(f)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(n(),p(K,{key:1,"kanban-repository":e(r)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(n(),p(h,{key:2,"kanban-repository":e(r),"workflow-api":e(a)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const we=v(W,[["__scopeId","data-v-8a8c88b2"]]);export{we as default};
//# sourceMappingURL=Threads.92dc9b2f.js.map
