import{a as g}from"./asyncComputed.bd2b6e70.js";import{d as y,ey as _,o as b,u as e,b as l,c as w,eq as C,f as a,w as o,cM as x,ak as c,cQ as h,bz as I,e as k,eC as v}from"./outputWidgets.f7b80e9f.js";import"./gateway.58b63376.js";import"./index.f21af923.js";import{O as z}from"./organization.542230b9.js";import{C as p}from"./router.6fb3acdf.js";import{L as B}from"./LoadingContainer.a8c11c78.js";import{A as D}from"./index.28e83ea9.js";import{C as M}from"./Card.3d001ab8.js";import"./popupNotifcation.6f5b518c.js";import"./record.188928bf.js";import"./pubsub.10df5fd2.js";import"./string.18a9daee.js";import"./TabPane.7d974707.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="08a7e5ea-0c6f-4f3d-9df0-66bcdb68c63e",t._sentryDebugIdIdentifier="sentry-dbid-08a7e5ea-0c6f-4f3d-9df0-66bcdb68c63e")}catch{}})();const N={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},K=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:f,result:u}=g(()=>z.get(s));b(()=>{location.search.includes("upgrade")&&p.showNewMessage("I want to upgrade my plan")});const m=()=>p.showNewMessage("I want to upgrade my plan");return(V,j)=>e(f)?(l(),w(B,{key:0})):(l(),C("div",N,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(x),{level:3},{default:o(()=>[c("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(M),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[c("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(u))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{K as default};
//# sourceMappingURL=Billing.4c9d91c4.js.map
