import{d as f,ey as b,eF as C,y as g,b as _,c as h,u as w,eL as I}from"./outputWidgets.f7b80e9f.js";import{b as k}from"./index.f21af923.js";import"./gateway.58b63376.js";import{C as i}from"./connector.fa7e7091.js";import{a as x}from"./asyncComputed.bd2b6e70.js";import{G as E}from"./PhPencil.vue.7371bf48.js";import{C as D}from"./CrudView.858975e6.js";import"./record.188928bf.js";import"./pubsub.10df5fd2.js";import"./string.18a9daee.js";import"./popupNotifcation.6f5b518c.js";import"./router.6fb3acdf.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b36f7510.js";import"./BookOutlined.12f9401e.js";import"./url.882128c4.js";import"./index.288a68e3.js";import"./index.86fdb625.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="3066d749-db9d-4cb9-9ab2-94afc860fd94",o._sentryDebugIdIdentifier="sentry-dbid-3066d749-db9d-4cb9-9ab2-94afc860fd94")}catch{}})();const H=f({__name:"Connectors",setup(o){const r=b(),a=C(),c=r.params.projectId;async function s(e){const t=await i.create(c,e.name,e.type);a.push({name:"connectorEditor",params:{connectorId:t.id}})}const p=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(k.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:d,result:l,refetch:m}=x(()=>i.list(c)),u=g(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"",align:"right"}],rows:(t=(e=l.value)==null?void 0:e.map(n=>({key:n.id,cells:[{type:"link",text:n.name,to:{name:"connectorEditor",params:{connectorId:n.id}}},{type:"text",text:n.type},{type:"actions",actions:[{icon:E,label:"Edit",onClick({key:y}){a.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:I,label:"Delete",dangerous:!0,async onClick(){await n.delete(),m()}}]}]})))!=null?t:[]}});return(e,t)=>(_(),h(D,{"entity-name":"connector",loading:w(d),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:p,"create-button-text":"Create connector",onCreate:s},null,8,["loading","table"]))}});export{H as default};
//# sourceMappingURL=Connectors.a157a62d.js.map
