import{B as d}from"./BookOutlined.12f9401e.js";import{d as c,b as a,c as l,w as o,f,u as n,dv as b,eq as u,ak as i,aw as p,bz as y}from"./outputWidgets.f7b80e9f.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="eb986570-bd9f-4b38-b996-ce8a06c9d8a4",t._sentryDebugIdIdentifier="sentry-dbid-eb986570-bd9f-4b38-b996-ce8a06c9d8a4")}catch{}})();const m=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[f(n(d))]),default:o(()=>[e.$slots.default?b(e.$slots,"default",{key:0}):(a(),u(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{m as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.b36f7510.js.map
