import{E as o,a as r,b as i,c,j as p,T as d,k as _,P as u,C as f,M as l,s as g,l as s,m,n as y,p as v,q as w}from"./outputWidgets.f7b80e9f.js";import{s as b,a}from"./index.8b4fa436.js";import"./fetch.1ec4f78f.js";import"./pubsub.10df5fd2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c8085828-a062-43f3-8e4a-557b46a70dfa",e._sentryDebugIdIdentifier="sentry-dbid-c8085828-a062-43f3-8e4a-557b46a70dfa")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{height:"100vh",width:"100%"}})}const k=o(h,[["render",I]]);class A{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const e=p({render:()=>m(k)});d.init(),_(e,a),A.init(),e.use(a),e.use(u),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,v),s(e,w)})();
//# sourceMappingURL=player.f2cfbdc7.js.map
