import{O as d}from"./index.8b4fa436.js";import{d as i,o as l,b as c,eq as u,f as t,w as n,u as o,ak as s,cM as f,cL as _}from"./outputWidgets.f7b80e9f.js";import"./fetch.1ec4f78f.js";import"./pubsub.10df5fd2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="de9aea57-8b29-4f2e-a065-af2432ca62e2",e._sentryDebugIdIdentifier="sentry-dbid-de9aea57-8b29-4f2e-a065-af2432ca62e2")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new d().loginCallback()}),(a,r)=>(c(),u("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(_),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.27a4eed8.js.map
