import{g as m}from"./api.aba07d9c.js";import{u as c}from"./index.8b4fa436.js";import{d as f,eF as d,ey as p,u as r,b as u,c as _,w as l,es as y,f as g,E as b}from"./outputWidgets.f7b80e9f.js";import{_ as h}from"./Login.vue_vue_type_script_setup_true_lang.47683020.js";import{a as w}from"./asyncComputed.bd2b6e70.js";import{W as I}from"./WidgetsFrame.e878f348.js";import"./runnerData.5347d4ed.js";import"./url.882128c4.js";import"./fetch.1ec4f78f.js";import"./pubsub.10df5fd2.js";import"./CircularLoading.b1d73f83.js";import"./index.9a5a7c1a.js";import"./PhArrowClockwise.vue.2d5eab39.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4d9b72f1-cd6d-4a42-8ef5-2988f425d086",e._sentryDebugIdIdentifier="sentry-dbid-4d9b72f1-cd6d-4a42-8ef5-2988f425d086")}catch{}})();const k=f({__name:"Login",setup(e){const t=d(),a=p(),{result:o}=w(m),i=async()=>{await c.signUp();const{redirect:s,...n}=a.query;if(s){await t.push({path:s,query:n,params:a.params});return}t.push({name:"playerHome",query:n})};return(s,n)=>r(o)?(u(),_(I,{key:0,"main-color":r(o).mainColor,theme:r(o).theme,"font-family":r(o).fontFamily,class:"runner"},{default:l(()=>[g(h,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):y("",!0)}});const H=b(k,[["__scopeId","data-v-b7ca18fc"]]);export{H as default};
//# sourceMappingURL=Login.f3907a17.js.map
