import{P as y}from"./PlayerNavbar.3d1d5e85.js";import{g as b}from"./api.aba07d9c.js";import{u as a}from"./index.8b4fa436.js";import{d as v,eF as w,r as k,ey as I,O as L,a as x,b as n,eq as s,f as c,u as i,E as D}from"./outputWidgets.f7b80e9f.js";import{a as M}from"./asyncComputed.bd2b6e70.js";import{L as C}from"./CircularLoading.b1d73f83.js";import"./metadata.e0926a4e.js";import"./PhCheckCircle.vue.902dac5a.js";import"./PhKanban.vue.34c60c18.js";import"./PhScroll.vue.26add44e.js";import"./PhWebhooksLogo.vue.4f41bfe0.js";import"./PhSignOut.vue.3641a16f.js";import"./index.956edd16.js";import"./runnerData.5347d4ed.js";import"./url.882128c4.js";import"./fetch.1ec4f78f.js";import"./pubsub.10df5fd2.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="150e8176-5c9a-4f2c-9efe-95ef6ac361cc",t._sentryDebugIdIdentifier="sentry-dbid-150e8176-5c9a-4f2c-9efe-95ef6ac361cc")}catch{}})();const E={class:"main-container"},N={key:0,class:"centered"},P={key:1,class:"content"},B=v({__name:"Main",setup(t){const e=w(),o=k(a.getUser()),p=I().path;a.pubsub.subscribe("authenticated",r=>{o.value=r});const m=({path:r})=>{e.push({path:`/${r}`})},d=()=>{e.push({name:"playerLogin"})},{result:_,loading:f,refetch:l}=M(b);L(o,l);const g=()=>{a.removeUser(),e.push({name:"playerHome"})};return(r,R)=>{var u;const h=x("router-view");return n(),s("div",E,[c(y,{"current-path":i(p),"runner-data":i(_),"user-email":(u=o.value)==null?void 0:u.claims.email,onNavigate:m,onLogout:g,onLogin:d},null,8,["current-path","runner-data","user-email"]),i(f)?(n(),s("div",N,[c(C)])):(n(),s("section",P,[c(h)]))])}}});const X=D(B,[["__scopeId","data-v-059bb8cc"]]);export{X as default};
//# sourceMappingURL=Main.57518d61.js.map
