import{cp as n}from"./outputWidgets.f7b80e9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="9ddb4ae7-01f7-4cb6-8221-c3585628a8cc",e._sentryDebugIdIdentifier="sentry-dbid-9ddb4ae7-01f7-4cb6-8221-c3585628a8cc")}catch{}})();const t=(e,r,d)=>{n.error({message:e,description:r,onClick:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.6f5b518c.js.map
