import{eU as n,eV as t}from"./outputWidgets.f7b80e9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="37df0080-8b4f-4847-9306-d927c4cd08d2",e._sentryDebugIdIdentifier="sentry-dbid-37df0080-8b4f-4847-9306-d927c4cd08d2")}catch{}})();function o(e,d){return n(1,arguments),t(e,Date.now(),d)}export{o as f};
//# sourceMappingURL=index.df77b543.js.map
