import{d as f,ey as _,eF as p,b as u,eq as y,f as i,w as a,u as r,c as g,es as m,ak as n,eC as c,cM as b,cI as h,bz as k,E as w}from"./outputWidgets.f7b80e9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new x().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6f106a41-e1c4-4513-8e05-3d9d7336079b",e._sentryDebugIdIdentifier="sentry-dbid-6f106a41-e1c4-4513-8e05-3d9d7336079b")}catch{}})();const I={class:"inner-content"},v=f({__name:"Error",setup(e){const t=_(),d=p(),o=()=>{const{status:s}=t.params;switch(s){case"404":return{status:s,title:"Page not found",message:"We couldn't find the page you were looking for."};case"403":return{status:s,title:"Access denied",message:"You tried to access a page you did not have prior authorization for. Please contact your administrator.",action:"Go back to home"};default:return{status:"500",title:"Internal server error",message:"An unknown error ocurred. Please try again or contact support."}}},l=()=>{d.push({name:"playerHome"})};return(s,C)=>(u(),y("div",I,[i(r(b),null,{default:a(()=>[n(c(o().title),1)]),_:1}),i(r(h),{class:"message"},{default:a(()=>[n(c(o().message),1)]),_:1}),o().action?(u(),g(r(k),{key:0,type:"primary",onClick:l},{default:a(()=>[n(c(o().action),1)]),_:1})):m("",!0)]))}});const x=w(v,[["__scopeId","data-v-c0d26e3f"]]);export{x as default};
//# sourceMappingURL=Error.0769b5a8.js.map
