import{Y as s,dc as i}from"./outputWidgets.f7b80e9f.js";import{g as a}from"./index.470210ec.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="c67939d2-6d9c-4d3b-8f33-6c844d593001",e._sentryDebugIdIdentifier="sentry-dbid-c67939d2-6d9c-4d3b-8f33-6c844d593001")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=a(i),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.aa11f9a1.js.map
