import{d as t,b as d,eq as o,f as s,u as r,bc as _,E as c}from"./outputWidgets.f7b80e9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a5312d5f-aee2-478a-81cd-baff3712b35a",e._sentryDebugIdIdentifier="sentry-dbid-a5312d5f-aee2-478a-81cd-baff3712b35a")}catch{}})();const f={class:"centered"},i=t({__name:"LoadingContainer",setup(e){return(n,a)=>(d(),o("div",f,[s(r(_))]))}});const u=c(i,[["__scopeId","data-v-1da18eee"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.a8c11c78.js.map
