import{C as t,E as d,K as i,a as f,M as c,c as b,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.d6977377.js";import"./outputWidgets.f7b80e9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c9147db4-11f5-4a14-9d90-a81f897ceb81",e._sentryDebugIdIdentifier="sentry-dbid-c9147db4-11f5-4a14-9d90-a81f897ceb81")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,f as KeyMod,c as MarkerSeverity,b as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.466c69c7.js.map
