import{E as d,b as o,eq as n,dv as s,e as a,es as r}from"./outputWidgets.f7b80e9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b6cbbb1f-47bc-4503-ac9b-d4007f86d0ab",e._sentryDebugIdIdentifier="sentry-dbid-b6cbbb1f-47bc-4503-ac9b-d4007f86d0ab")}catch{}})();const c={},f={class:"base-layout"},b={class:"base-middle"},i={key:0,class:"base-footer"};function u(e,t){return o(),n("div",f,[s(e.$slots,"navbar",{},void 0,!0),a("section",b,[s(e.$slots,"sidebar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0)]),e.$slots.footer?(o(),n("section",i,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])}const y=d(c,[["render",u],["__scopeId","data-v-e54815f3"]]);export{y as B};
//# sourceMappingURL=BaseLayout.c5d4e2a2.js.map
